@@ -41,6 +41,7 @@ class BaseSessionTest(unittest.TestCase):
             'config_file': (None, 'FOO_CONFIG_FILE', None, None),
             'credentials_file': (None, None, '/tmp/nowhere', None),
             'ca_bundle': ('foo_ca_bundle', 'FOO_AWS_CA_BUNDLE', None, None),
+            'api_versions': ('foo_api_versions', None, {}, None)
         }
         self.environ = {}
         self.environ_patch = mock.patch('os.environ', self.environ)
@@ -554,6 +555,75 @@ class TestCreateClient(BaseSessionTest):
             # configurations
             self.assertEqual(call_kwargs['verify'], 'verify-certs.pem')
 
+    @mock.patch('botocore.client.ClientCreator')
+    def test_create_client_use_no_api_version_by_default(self, client_creator):
+        self.session.create_client('myservice', 'us-west-2')
+        call_kwargs = client_creator.return_value.create_client.call_args[1]
+        self.assertEqual(call_kwargs['api_version'], None)
+
+    @mock.patch('botocore.client.ClientCreator')
+    def test_create_client_uses_api_version_from_config(self, client_creator):
+        config_api_version = '2012-01-01'
+        with temporary_file('w') as f:
+            del self.environ['FOO_PROFILE']
+            self.environ['FOO_CONFIG_FILE'] = f.name
+            self.session = create_session(session_vars=self.env_vars)
+            f.write('[default]\n')
+            f.write('foo_api_versions =\n'
+                    '    myservice = %s\n' % config_api_version)
+            f.flush()
+
+            self.session.create_client('myservice', 'us-west-2')
+            call_kwargs = client_creator.return_value.\
+                create_client.call_args[1]
+            self.assertEqual(call_kwargs['api_version'], config_api_version)
+
+    @mock.patch('botocore.client.ClientCreator')
+    def test_can_specify_multiple_versions_from_config(self, client_creator):
+        config_api_version = '2012-01-01'
+        second_config_api_version = '2013-01-01'
+        with temporary_file('w') as f:
+            del self.environ['FOO_PROFILE']
+            self.environ['FOO_CONFIG_FILE'] = f.name
+            self.session = create_session(session_vars=self.env_vars)
+            f.write('[default]\n')
+            f.write('foo_api_versions =\n'
+                    '    myservice = %s\n'
+                    '    myservice2 = %s\n' % (
+                        config_api_version, second_config_api_version)
+            )
+            f.flush()
+
+            self.session.create_client('myservice', 'us-west-2')
+            call_kwargs = client_creator.return_value.\
+                create_client.call_args[1]
+            self.assertEqual(call_kwargs['api_version'], config_api_version)
+
+            self.session.create_client('myservice2', 'us-west-2')
+            call_kwargs = client_creator.return_value.\
+                create_client.call_args[1]
+            self.assertEqual(
+                call_kwargs['api_version'], second_config_api_version)
+
+    @mock.patch('botocore.client.ClientCreator')
+    def test_param_api_version_overrides_config_value(self, client_creator):
+        config_api_version = '2012-01-01'
+        override_api_version = '2014-01-01'
+        with temporary_file('w') as f:
+            del self.environ['FOO_PROFILE']
+            self.environ['FOO_CONFIG_FILE'] = f.name
+            self.session = create_session(session_vars=self.env_vars)
+            f.write('[default]\n')
+            f.write('foo_api_versions =\n'
+                    '    myservice = %s\n' % config_api_version)
+            f.flush()
+
+            self.session.create_client(
+                'myservice', 'us-west-2', api_version=override_api_version)
+            call_kwargs = client_creator.return_value.\
+                create_client.call_args[1]
+            self.assertEqual(call_kwargs['api_version'], override_api_version)
+
 
 class TestComponentLocator(unittest.TestCase):
     def setUp(self):
